package java.rmi;

import java.net.MalformedURLException;
import java.net.URL;
import java.rmi.registry.LocateRegistry;
import java.rmi.registry.Registry;

public final class Naming {
   private Naming() {
   }

   public static Remote lookup(String var0) throws NotBoundException, MalformedURLException, UnknownHostException, RemoteException {
      URL var1 = cleanURL(var0);
      Registry var2 = getRegistry(var1);
      String var3 = getName(var1);
      return (Remote)(var3 == null ? var2 : var2.lookup(var3));
   }

   public static void bind(String var0, Remote var1) throws AlreadyBoundException, MalformedURLException, UnknownHostException, RemoteException {
      URL var2 = cleanURL(var0);
      Registry var3 = getRegistry(var2);
      if (var1 == null) {
         throw new NullPointerException("cannot bind to null");
      } else {
         var3.bind(getName(var2), var1);
      }
   }

   public static void unbind(String var0) throws RemoteException, NotBoundException, MalformedURLException, UnknownHostException {
      URL var1 = cleanURL(var0);
      Registry var2 = getRegistry(var1);
      var2.unbind(getName(var1));
   }

   public static void rebind(String var0, Remote var1) throws RemoteException, MalformedURLException, UnknownHostException {
      URL var2 = cleanURL(var0);
      Registry var3 = getRegistry(var2);
      if (var1 == null) {
         throw new NullPointerException("cannot bind to null");
      } else {
         var3.rebind(getName(var2), var1);
      }
   }

   public static String[] list(String var0) throws RemoteException, MalformedURLException, UnknownHostException {
      URL var1 = cleanURL(var0);
      Registry var2 = getRegistry(var1);
      String var3 = var1.getHost();
      int var4 = var1.getPort();
      String var5 = "rmi:";
      if (var4 > 0 || !var3.equals("")) {
         var5 = var5 + "//" + var3;
      }

      if (var4 > 0) {
         var5 = var5 + ":" + var4;
      }

      var5 = var5 + "/";
      String[] var6 = var2.list();

      for(int var7 = 0; var7 < var6.length; ++var7) {
         var6[var7] = var5 + var6[var7];
      }

      return var6;
   }

   private static Registry getRegistry(URL var0) throws RemoteException, UnknownHostException {
      String var1 = var0.getHost();
      int var2 = var0.getPort();
      return LocateRegistry.getRegistry(var1, var2);
   }

   private static String getName(URL var0) {
      String var1 = var0.getFile();
      return var1 != null && !var1.equals("/") ? var1.substring(1) : null;
   }

   private static URL cleanURL(String var0) throws MalformedURLException {
      URL var1 = new URL("file:");
      if (var0.startsWith("rmi:")) {
         var0 = var0.substring(4);
      }

      int var2 = var0.indexOf(58);
      if (var2 >= 0 && var2 < var0.indexOf(47)) {
         throw new MalformedURLException("Protocol should be rmi:");
      } else {
         var1 = new URL(var1, var0);
         return var1;
      }
   }
}
